Module server

Module server 

Server module

Structs

Server
Asynchronous HTTP server that listens on a TCP socket and handles requests. It will serves static and dynamic routes via a Router and logs each request with a Logger

Functions

handle_client
Handles a single TCP connection, it can process multiple HTTP requests if keep-alive is used