pub struct Server<'a> { /* private fields */ }Expand description
Asynchronous HTTP server that listens on a TCP socket and handles requests.
It will serves static and dynamic routes via a Router and logs each request with a Logger
Implementations
Sourceimpl<'a> Server<'a>
impl<'a> Server<'a>
Sourcepub fn with_address(addr: &'a str) -> Result<Self, String>
pub fn with_address(addr: &'a str) -> Result<Self, String>
Creates a new server bound to addr, reading the configuration from a file named config.toml or used the default configuration
Errors
Returns an error if the configuration or logger initialization fails