pub struct Logger { /* private fields */ }Expand description
Logger used to record HTTP request information into a log file.
Implementations
Sourceimpl Logger
impl Logger
Sourcepub fn new(path: &str) -> IoResult<Self>
pub fn new(path: &str) -> IoResult<Self>
Creates a new logger writing to the file at the given path.
If the file does not exist, it is created. Otherwise, logs are appended.
Errors
Returns an error if the file cannot be opened or created.